# Changelog

## [0.2.11a1](https://github.com/OpenVoiceOS/ovos-PHAL/tree/0.2.11a1) (2025-11-05)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-PHAL/compare/0.2.10...0.2.11a1)

**Merged pull requests:**

- Update ovos-plugin-manager version constraint [\#63](https://github.com/OpenVoiceOS/ovos-PHAL/pull/63) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
